@@ -48,7 +48,8 @@ class FreqDict(models.Model):
             ls.append(Lemma(pk=int(key),FreqDict=self,Label=lemmas[key]['Word'],Category=cat,Frequency=int(lemmas[key]['Freq'])))
         Lemma.objects.bulk_create(ls)
         for key in wfs:
-            wf = WordForm.objects.create(pk=int(key),Frequency = int(wfs[key]['Freq']))
+            lem = Lemma.objects.get(pk=int(wfs[key]['IdLemma']))
+            wf = WordForm.objects.create(pk=int(key),Lemma = lem,Frequency = int(wfs[key]['Freq']))
             ss = (Orthography.objects.get_or_create(Spelling=s)[0] for s in wfs[key]['Spellings'])
             wf.Orthographies.add(*ss)
             ts = (Transcription.objects.get_or_create(Transcription=t)[0] for t in wfs[key]['Transcriptions'])
